@@ -40,5 +40,5 @@ summary(mv, output = "r")
 ## ----fig.height=5-------------------------------------------------------------
 spec_summary(mv, var = "log(lstat)") |>
   spec_curve(label = "code") +
-  ggplot2::labs("Significant at 0.05")
+  ggplot2::labs(colour = "Significant at 0.05")
 
